#ifndef __CDDA2WAV_H
#define __CDDA2WAV_H


#include "options.h"
int cdda2wav(WINDOW *mainwin, struct conf *config);


#endif /* __CDDA2WAW */
